<?php
/**
 * Blocks Initializer
 *
 * Enqueue CSS/JS of all the blocks.
 *
 * @since   1.0.0
 */

// Exit if accessed directly.
if (!defined('ABSPATH')) {
    exit;
}

/**
 * Enqueue Gutenberg block assets for both frontend + backend.
 *
 * `wp-blocks`: includes block type registration and related functions.
 *
 * @since 1.0.0
 */
function guten_post_layout_frontend_assets()
{
    wp_enqueue_style(
        'guten_post_layout-style-css',
        plugins_url('dist/blocks.style.build.css', dirname(__FILE__)),
        array(),
        filemtime(plugin_dir_path(__DIR__).'dist/blocks.style.build.css')
    );
    
    wp_enqueue_script(
        'guten_post_layout-slick-min',
        plugins_url('src/assets/js/slick.min.js', dirname(__FILE__)),
        array(),
        filemtime(plugin_dir_path(__DIR__).'src/assets/js/slick.min.js'),
        true
    );

    wp_enqueue_script(
        'guten_post_layout-custom',
        plugins_url('src/assets/js/custom.js', dirname(__FILE__)),
        array(),
        filemtime(plugin_dir_path(__DIR__).'src/assets/js/custom.js'),
        true
    );

    wp_enqueue_style(
        'guten_post_layout-slick',
        plugins_url('src/assets/css/slick.css', dirname(__FILE__)),
        array(),
        filemtime(plugin_dir_path(__DIR__).'src/assets/css/slick.css')
    );

    wp_enqueue_style(
        'guten_post_layout-slick-theme',
        plugins_url('src/assets/css/slick-theme.css', dirname(__FILE__)),
        array(),
        filemtime(plugin_dir_path(__DIR__).'src/assets/css/slick-theme.css')
    );
}

// Hook: Frontend assets.
add_action('enqueue_block_assets', 'guten_post_layout_frontend_assets');

/**
 * Enqueue Gutenberg block assets for backend editor.
 *
 * `wp-blocks`: includes block type registration and related functions.
 * `wp-element`: includes the WordPress Element abstraction for describing the structure of your blocks.
 * `wp-i18n`: To internationalize the block's text.
 *
 * @since 1.0.0
 */
function guten_post_layout_editor_assets()
{
    wp_enqueue_script(
        'guten_post_layout-js',
        plugins_url('dist/blocks.build.js', dirname(__FILE__)),
        array('wp-blocks', 'wp-i18n', 'wp-element', 'wp-components' , 'wp-editor' ),
        filemtime(plugin_dir_path(__DIR__).'dist/blocks.build.js'),
        true
    );

    wp_enqueue_style(
        'guten_post_layout-editor-css',
        plugins_url('dist/blocks.editor.build.css', dirname(__FILE__)),
        array('wp-edit-blocks'),
        filemtime(plugin_dir_path(__DIR__).'dist/blocks.editor.build.css')
    );
}

// Hook: Editor assets.
add_action('enqueue_block_editor_assets', 'guten_post_layout_editor_assets');
