<?php
/**
 * @author  rs-theme
 * @since   1.0
 * @version 1.0 
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function hepta_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	return $classes;
}
add_filter( 'body_class', 'hepta_body_classes' );

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function hepta_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}

add_action( 'wp_head', 'hepta_pingback_header' );

/*
Register Fonts theme google font
*/
function hepta_studio_fonts_url() {
    $font_url = '';
    
    /*
    Translators: If there are characters in your language that are not supported
    by chosen font(s), translate this to 'off'. Do not translate into your own language.
     */
    if ( 'off' !== _x( 'on', 'Google font: on or off', 'hepta' ) ) {
        $font_url = add_query_arg( 'family', urlencode( 'Poppins|Roboto:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i&amp;subset=latin-ext' ), "//fonts.googleapis.com/css" );
    }
    return $font_url;
}
/*
Enqueue scripts and styles.
*/
function hepta_studio_scripts() {
    wp_enqueue_style( 'studio-fonts', hepta_studio_fonts_url(), array(), '1.0.0' );
}
add_action( 'wp_enqueue_scripts', 'hepta_studio_scripts' );


//Favicon Icon
function hepta_site_icon() {
 if ( ! ( function_exists( 'has_site_icon' ) && has_site_icon() ) ) {     
  	global $hepta_option;
  	 
  	if(!empty($hepta_option['rs_favicon']['url']))
  	{?>
		<link rel="shortcut icon" type="image/x-icon" href="<?php echo esc_url(($hepta_option['rs_favicon']['url'])); ?>">	
 	<?php 
 		}
	}
}
add_filter('wp_head', 'hepta_site_icon');

function hepta_add_excerpt_support_for_cpt() {
 add_post_type_support( 'services', 'excerpt' );
}
add_action( 'init', 'hepta_add_excerpt_support_for_cpt' );

//excerpt for specific section

function hepta_wpex_get_excerpt( $args = array() ) {
  // Defaults
  $defaults = array(
    'post'            => '',
    'length'          => 48,
    'readmore'        => false,
    'readmore_text'   => esc_html__( 'read more', 'hepta' ),
    'readmore_after'  => '',
    'custom_excerpts' => true,
    'disable_more'    => false,
  );
  // Apply filters
  $defaults = apply_filters( 'hepta_wpex_get_excerpt_defaults', $defaults );
  // Parse args
  $args = wp_parse_args( $args, $defaults );
  // Apply filters to args
  $args = apply_filters( 'hepta_wpex_get_excerpt_args', $defaults );
  // Extract
  extract( $args );
  // Get global post data
  if ( ! $post ) {
    global $post;
  }

  // Get post ID
  $post_id = $post->ID;

  // Check for custom excerpt
  if ( $custom_excerpts && has_excerpt( $post_id ) ) {
    $output = $post->post_excerpt;
  }
  // No custom excerpt...so lets generate one
  else {
    // Readmore link
    $readmore_link = '<a href="' . get_permalink( $post_id ) . '" class="readmore">' . $readmore_text . $readmore_after . '</a>';
    // Check for more tag and return content if it exists
    if ( ! $disable_more && strpos( $post->post_content, '<!--more-->' ) ) {
      $output = apply_filters( 'the_content', get_the_content( $readmore_text . $readmore_after ) );
    }
    // No more tag defined so generate excerpt using wp_trim_words
    else {
      // Generate excerpt
      $output = wp_trim_words( strip_shortcodes( $post->post_content ), $length );
      // Add readmore to excerpt if enabled
      if ( $readmore ) {
        $output .= apply_filters( 'hepta_wpex_readmore_link', $readmore_link );
      }

    }

  }
  // Apply filters and echo
  return apply_filters( 'hepta_wpex_get_excerpt', $output );
}


//Demo content file include here

function hepta_import_files() {
  return array(
    array(
      'import_file_name'           => 'Hepta Demo Import',
      'categories'                 => array( 'Category 1' ),
      'import_file_url'            => trailingslashit( get_template_directory_uri() ) . 'ocdi/hepta.wordpress.xml',
      'import_widget_file_url'     => trailingslashit( get_template_directory_uri() ) . 'ocdi/hepta-widgets.wie',      
      'import_redux'               => array(
        array(
          'file_url'    => trailingslashit( get_template_directory_uri() ) . 'ocdi/redux_options_hepta.json',
          'option_name' => 'hepta_option',
        ),
      ),
      
      'import_notice'              => __( 'Caution: For importing demo data please click on "Import Demo Data" button. During demo data installation please do not refresh the page.', 'mifo' ),
      
    ),
    
  );
}

add_filter( 'pt-ocdi/import_files', 'hepta_import_files' );

function hepta_after_import_setup() {
  // Assign menus to their locations.
  $main_menu   = get_term_by( 'name', 'Primary Menu', 'nav_menu' );
  $left_menu   = get_term_by( 'name', 'Menu Left', 'nav_menu' );
  $right_menu  = get_term_by( 'name', 'Menu right', 'nav_menu' );
  $footer_menu = get_term_by( 'name', 'Footer Menu', 'nav_menu' );  

  set_theme_mod( 'nav_menu_locations', array(
      'menu-1' => $main_menu->term_id,  
      'menu-2' => $left_menu->term_id,
      'menu-3' => $right_menu->term_id,
      'menu-4' => $footer_menu->term_id    
    )
  );

  // Assign front page and posts page (blog page).
  $front_page_id = get_page_by_title( 'Home' );
  $blog_page_id  = get_page_by_title( 'Blog' );

  update_option( 'show_on_front', 'page' );
  update_option( 'page_on_front', $front_page_id->ID );
  update_option( 'page_for_posts', $blog_page_id->ID ); 

  //Import Revolution Slider
  if ( class_exists( 'RevSlider' ) ) {
     $slider_array = array(
        get_template_directory()."/ocdi/slider/classic.zip",
        get_template_directory()."/ocdi/slider/consulting.zip",
        get_template_directory()."/ocdi/slider/corporate.zip",
        get_template_directory()."/ocdi/slider/creative.zip",
        get_template_directory()."/ocdi/slider/home.zip",
        get_template_directory()."/ocdi/slider/home-gym.zip",
        get_template_directory()."/ocdi/slider/home-lawyer.zip",
        get_template_directory()."/ocdi/slider/home-restaurant.zip",
        get_template_directory()."/ocdi/slider/homeseo.zip",
        get_template_directory()."/ocdi/slider/home-slider.zip",
        get_template_directory()."/ocdi/slider/Medical.zip",
        get_template_directory()."/ocdi/slider/apps-slider.zip",         
        get_template_directory()."/ocdi/slider/onepage2.zip",
        get_template_directory()."/ocdi/slider/startup.zip",
        get_template_directory()."/ocdi/slider/tattoo.zip"       
        );

     $slider = new RevSlider();

     foreach($slider_array as $filepath){
       $slider->importSliderFromPost(true,true,$filepath);  
     }
  } 
}
add_action( 'pt-ocdi/after_import', 'hepta_after_import_setup' );
